@@ -3,6 +3,7 @@ package docker
 import (
 	"context"
 	"fmt"
+	"io"
 
 	"github.com/docker/cli/cli/streams"
 	"github.com/docker/docker/api/types"
@@ -12,23 +13,38 @@ import (
 
 type Client struct {
 	client.CommonAPIClient
-	aux *streams.Out
+	out *streams.Out
 }
 
 var _ client.CommonAPIClient = &Client{}
 
-func NewClient(aux *streams.Out) (*Client, error) {
-	inner, err := client.NewClientWithOpts(
+type Options struct {
+	Out  *streams.Out
+	Host string
+}
+
+func NewClient(opts Options) (*Client, error) {
+	dockerOpts := []client.Opt{
 		client.FromEnv,
 		client.WithAPIVersionNegotiation(),
-	)
+	}
+	if len(opts.Host) > 0 {
+		dockerOpts = append(dockerOpts, client.WithHost(opts.Host))
+	}
+
+	inner, err := client.NewClientWithOpts(dockerOpts...)
 	if err != nil {
 		return nil, fmt.Errorf("cannot initialize Docker client: %w", err)
 	}
 
+	out := opts.Out
+	if out == nil {
+		out = streams.NewOut(io.Discard)
+	}
+
 	return &Client{
 		CommonAPIClient: inner,
-		aux:             aux,
+		out:             out,
 	}, nil
 }
 
@@ -43,5 +59,5 @@ func (c *Client) ImagePullEx(
 	}
 	defer resp.Close()
 
-	return jsonmessage.DisplayJSONMessagesToStream(resp, c.aux, nil)
+	return jsonmessage.DisplayJSONMessagesToStream(resp, c.out, nil)
 }
